import babel from 'rollup-plugin-babel';
import resolve from '@rollup/plugin-node-resolve';
import external from 'rollup-plugin-peer-deps-external';
import { terser } from 'rollup-plugin-terser';
import postcss from 'rollup-plugin-postcss';
import commonjs from "@rollup/plugin-commonjs";
import json from '@rollup/plugin-json'
import nodePolyfills from 'rollup-plugin-node-polyfills';
import image from "@rollup/plugin-image"
import copy from 'rollup-plugin-copy'

export default [
  {
    input: './src/index.js',
    output: [
      {
        file: './dist/index.js',
        format: 'cjs',
      },
      {
        file: './dist/index.es.js',
        format: 'es',
        exports: 'named',
      }
    ],
    inlineDynamicImports: true,
    sourceMap: 'inline',
    plugins: [
      postcss({
        plugins: [],
        minimize: true,
      }),
      babel({
        exclude: 'node_modules/**',
        presets: ['@babel/preset-env' , 
                 '@babel/preset-react'
                ],
       plugins:[
        [ "react-remove-properties", {"properties": ["data-testid", "data-foo" ,"data-test-id"]}],
        ["babel-plugin-styled-components"],
        ["babel-plugin-macros"]
       ]
      }),
      external(),
      commonjs(),
      resolve(),
      terser(),
      json(),
      nodePolyfills(),
      image({
        limit: 100000,
      }),
      copy({
        targets: [
          { src: ['src/static/fontello/*'], dest: 'dist/static' },
        ]
      })
    ],
    external: [
        'react',
        'react-dom',
      ],
  }
];
