import { css } from '@emotion/css'
import React from 'react'
import tw, { styled } from 'twin.macro'
import Label from '../Label'
import PropTypes from 'prop-types'



const StyledAnchor = styled.a(({ twProps }) => [
    twProps,
])

const StyledImg = styled.img(({ twProps }) => [
    twProps,
    {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
    },
])

const StyledBoxImg = styled.div(({ twProps }) => [
    twProps,
    {
        position: 'relative',
        paddingTop: '70%',
    },
])


const CardSalePage = (props) => {
    const {
        targetType = "newTab",
        image = "",
        domainName = " ",
        title = " ",
        description = " ",
    } = props

    const isCanLink = (domainName !== "#") && (domainName !== " ") && (domainName?.length > 0)
    const target = (targetType == null || targetType == "newTab") ? '_blank' : '_self'

    return (
        <StyledAnchor
            href={domainName}
            target={target}
            onClick={(e) => {
                if (!isCanLink) {
                    e.preventDefault();
                    return false;
                }
            }}
            twProps={tw`bg-white p-[12px] rounded-card shadow-cardSalePage flex flex-col`}
            className={css`
                cursor: ${isCanLink ? 'pointer' : 'default'};
                text-decoration: none;
                * {
                    cursor: ${isCanLink ? 'pointer' : 'default'};
                }
                img{
                    object-fit: contain;
                }
                :hover{
                    img{
                        filter: brightness(1.08);
                    }
                }
                `}
        >
            {/* <div tw='mb-[12px]'>
                    <Image
                        width={600}
                        height={400}
                        layout='responsive'
                        loader={() => image}
                        src={image}
                        alt={`card-salepage-${title}`}
                        tw=' rounded-card text-transparent'
                    />
                </div> */}
            <StyledBoxImg twProps={tw`mb-[12px]`}>
                <StyledImg
                    twProps={tw`text-transparent `}
                    src={image}
                    alt={`card-salepage-${title}`}
                    width={'100%'}
                    height={'100%'}
                />
            </StyledBoxImg>
            <Label
                text={domainName || " "}
                fontSize={12}
                fontWeight={400}
                textAlign={'start'}
                twColor={tw`text-defaultTextInput`}
                twProps={tw`mb-[4px] line-clamp-1 min-h-[25px] break-all leading-[24px]`}
            />
            <Label
                text={title || " "}
                fontSize={16}
                fontWeight={400}
                textAlign={'start'}
                twColor={tw`text-defaultTextPrimary`}
                twProps={tw`mb-[4px] line-clamp-2 min-h-[56px] break-all leading-[28px]`}
            />
            <Label
                text={description || " "}
                fontSize={12}
                fontWeight={400}
                textAlign={'start'}
                twColor={tw`text-textTertiary`}
                twProps={tw`line-clamp-1 min-h-[25px] break-all leading-[24px]`}
            />

        </StyledAnchor>
    )
}

CardSalePage.propTypes = {
    targetType: PropTypes.string,
    image: PropTypes.string,
    domainName: PropTypes.string,
    title: PropTypes.string,
    description: PropTypes.string,
};

CardSalePage.defaultProps = {
    targetType: "newTab",
    image: "",
    domainName: " ",
    title: " ",
    description: " ",
};

export default CardSalePage