import { css } from '@emotion/css'
import React from 'react'
import CardSalePage from '../CardSalePage'
import TitleText from '../TitleText'
import PropTypes from 'prop-types'

const CardSalePageWidget = (props) => {
    const {
        data = [],
        marginBottom = 0,
        marginLeft = 0,
        marginRight = 0,
        isOneColumn = false,
        theme,
        titleText = 'รายการทั้งหมด',
        marginBottomTitleText = 22,
    } = props

    return (
        <div>
            <TitleText tagColor={theme?.primary} color={theme?.fontColor} marginBottom={marginBottomTitleText}>{titleText}</TitleText>
            <div
                className={css`
                margin-left:${marginLeft}px;
                margin-right:${marginRight}px;
                margin-bottom: ${marginBottom}px;
                display: grid;
                grid-template-columns: repeat(${isOneColumn ? 1 : 3}, minmax(0,1fr));
                gap: 12px;
                @media (max-width:767px){
                    grid-template-columns: repeat(1, minmax(0,1fr)) !important;
                }
              `}
            >
                {
                    data.map((item, index) => {
                        return (
                            <div key={`card-${index}`}>
                                <CardSalePage
                                    targetType={item?.targetType}
                                    image={item?.image}
                                    domainName={item?.domainName}
                                    title={item?.title}
                                    description={item?.description}
                                />
                            </div>
                        )
                    })
                }
            </div>
        </div>
    )
}


CardSalePageWidget.propTypes = {
    data: PropTypes.array,
    marginBottom: PropTypes.number,
    marginLeft: PropTypes.number,
    marginRight: PropTypes.number,
    isOneColumn: PropTypes.bool,
    theme: PropTypes.object,
    titleText: PropTypes.string,
    marginBottomTitleText: PropTypes.number,
};

CardSalePageWidget.defaultProps = {
    data: [],
    marginBottom: 0,
    marginLeft: 0,
    marginRight: 0,
    isOneColumn: false,
    theme: {},
    titleText: 'รายการทั้งหมด',
    marginBottomTitleText: 22,
};

export default CardSalePageWidget