import React from 'react'
import PropTypes from 'prop-types'
import { css } from '@emotion/css'
import TitleText from '../TitleText/TitleText'
import { styled } from 'twin.macro'
import '../../static/fontello/css/fontello.css'

const CartWidget = (props) => {
  const { theme = { primary: '#26D496' } } = props

  const EmptyCart = () => {
    return (
      <div
        className={css`
          background-color: #f9f9f9;
          border-radius: 10px;
          padding: 1.875rem 2.5rem;
          @media (max-width:767px){
             padding: 15px;
          }
        `}
      >
        <i
          className={`icon-empty-cart ${css`
            font-size: 20px;
            color: #aeafaf;
          `}`}
        />
        <label
          className={css`
            color: #aeafaf;
            padding-left: 10px;
            font-size: 16px;
            font-family: 'Kanit', sans-serif;
          `}
        >
          ยังไม่มีสินค้าในตะกร้า
        </label>
      </div>
    )
  }

  const Promotion = () => {
    return (
      <div>
        <p
          className={css`
            font-family: 'Kanit', sans-serif;
          `}
        >
          โค้ดส่วนลด
        </p>

        <div
          className={css`
            position: relative;
            width: 100%;
          `}
        >
          <input
            placeholder='กรอกโค้ดส่วนลด'
            className={css`
              background-color: #f9f9f9;
              border: 1px solid #f2f2f2;
              border-radius: 10px;
              width: -webkit-fill-available;
              padding: 12px;
              font-size: 16px;
              font-family: 'Kanit', sans-serif;

              &::placeholder {
                color: #aeafaf;
              }

              &:focus {
                outline: none;
              }
            `}
          />
          <button
            className={css`
              position: absolute;
              right: 10px;
              top: 8px;
              background-color: ${theme.primary ? theme.primary : '#26D496'};
              color: white;
              border: none;
              padding: 5px 10px;
              border-radius: 10px;
              font-weight: 500;
              font-size: 14px;
              font-family: 'Kanit', sans-serif;

              &:hover {
                cursor: pointer;
              }
            `}
          >
            ใช้งาน
          </button>
        </div>
      </div>
    )
  }

  const Note = () => {
    return (
      <div
        className={css`
          width: 100%;
          margin-top: 20px;
        `}
      >
        <p
          className={css`
            font-family: 'Kanit', sans-serif;
          `}
        >
          หมายเหตุ (ข้อความถึงผู้ขาย)
        </p>

        <textarea
          rows={3}
          className={css`
            background: #f9f9f9;
            border: 1px solid #f2f2f2;
            border-radius: 10px;
            padding: 10px 15px;
            width: -webkit-fill-available;
            font-family: 'Kanit', sans-serif;
            font-weight: 400;
            font-size: 16px;

            &::placeholder {
              color: #aeafaf;
            }

            &:focus {
              outline: none;
            }
          `}
          placeholder='กรอกข้อความ'
        />
      </div>
    )
  }

  const StyledText = styled.label(({ fontSize, fontWeight, color }) => [
    `
    font-weight: ${fontWeight ? fontWeight : '400'};
    font-size: ${fontSize ? fontSize : '16px'};
    color: ${color ? color : '#2a2c2d'};
    font-family: 'Kanit', sans-serif;
   `,
  ])

  const SummaryPrice = () => {
    return (
      <div
        className={css`
          margin-top: 15px;
        `}
      >
        <div
          className={css`
            display: flex;
            justify-content: space-between;
          `}
        >
          <StyledText>ค่าสินค้า</StyledText>
          <StyledText>฿ 0</StyledText>
        </div>

        <div
          className={css`
            display: flex;
            justify-content: space-between;
            margin-top: 10px;
          `}
        >
          <StyledText fontSize={'18px'} fontWeight={600}>
            ราคารวม
          </StyledText>
          <StyledText fontWeight={600} fontSize={'18px'} color={theme.primary ? theme.primary : '#26D496'}>
            ฿ 0
          </StyledText>
        </div>
      </div>
    )
  }

  return (
    <div>
      <TitleText children='ตะกร้า' tagColor={theme.primary} />
      <div
        className={css`
          margin-top: 20px;
        `}
      >
        <EmptyCart />

        <div
          className={css`
            background: white;
            border-radius: 10px;
            margin-top: 15px;
            padding: 1.875rem 2.5rem;
            @media (max-width:767px){
            padding: 10px 15px;
             /* padding: 15px; */
          }
          `}
        >
          <Promotion />
          <Note />
          <SummaryPrice />
        </div>
      </div>
    </div>
  )
}

CartWidget.propTypes = {
  theme: PropTypes.shape({
    primary: PropTypes.string,
  }),
}

CartWidget.defaultProps = {
  theme: { primary: '#95BAA8' },
}

export default CartWidget
