import React from 'react'
import PropTypes from 'prop-types';
import { css } from '@emotion/css'
import classNames from 'classnames';

const ImageSetWidget = (props) => {
  const {
    display,
    link,
    targetType,
    alt,
    data,
    column,
    bgColorImage,
    marginBottom = 0,
    marginLeft = 0,
    marginRight = 0,
    isDisplayColumn = false,
    isOneColumn = false,
    gap = 0,
  } = props


  const isCanLink = (link !== "#") && (link?.length > 0)
  const target = (targetType == "newTab") ? '_blank' : '_self'

  if (data.length <= 0) {
    return null
  }

  return (
    <div
      className={classNames(css`
        position: relative;
        height: 100%;
        width: 100%;
        display: flex;
        flex-direction: column;
        justify-content: ${isDisplayColumn ? 'start' : 'center'};
        align-items: center;
        text-decoration: none;
        margin-bottom: ${marginBottom}px;
      `,
      )}
    >

      <div
        className={classNames(css`
          margin-left:${marginLeft}px;
          margin-right:${marginRight}px;
          margin-top: 0;
          margin-bottom: 0;
          display: grid;
          grid-template-columns: repeat(${isOneColumn && !isDisplayColumn ? 1 : column}, 1fr);
          /* gap: ${isDisplayColumn ? '0px' : ' 8px'}; */
          gap: ${gap ? gap + 'px' : '0px'};
          @media (max-width:767px){
            grid-template-columns: repeat(${isDisplayColumn ? column : 1}, 1fr);
          }
        `,
        )}
      >
        {
          data.map((item, index) => {
            return (
              <a
                target={target}
                href={link}
                onClick={(e) => {
                  if (!isCanLink) {
                    e.preventDefault();
                    return false;
                  }
                }}
                key={`image-set-${index}`}
                className={classNames(css`
                  display: flex;
                  flex-direction: column;
                  justify-content: ${isDisplayColumn ? 'start' : 'center'};
                  align-items: center;
                  background-color: ${bgColorImage};
                  cursor: ${isCanLink ? 'pointer' : 'default'};
                  div:hover{
                    cursor: ${isCanLink ? 'pointer' : 'default'};
                    img:hover{
                      cursor: ${isCanLink ? 'pointer' : 'default'};
                    }
                  }
                `)}
              >
                <img
                  src={item}
                  alt={`${index}-${alt}`}
                  className={css`
                    height: auto;
                    width: ${display == 'standard' ? 'unset' : '100vw'};
                  `}
                />
              </a>
            )
          })}
      </div>

    </div >
  )
}


ImageSetWidget.propTypes = {
  display: PropTypes.string,
  link: PropTypes.string,
  alt: PropTypes.string,
  targetType: PropTypes.string,
  data: PropTypes.any,
  column: PropTypes.number,
  bgColorImage: PropTypes.string,
  marginBottom: PropTypes.number,
};

ImageSetWidget.defaultProps = {
  display: 'standard',
  link: '#',
  targetType: 'default',
  alt: 'ImageSet',
  data: [],
  column: 1,
  bgColorImage: 'transparent',
  marginBottom: 0,
};


export default ImageSetWidget


