import React from 'react'
import PropTypes from 'prop-types';
import { css } from '@emotion/css'
import classNames from 'classnames';

const ImageWidget = (props) => {
  const {
    src,
    link,
    alt,
    targetType,
    objectFit,
    height,
    width,
    marginBottom = 0,
    marginLeft = 0,
    marginRight = 0,
  } = props


  const isCanLink = (link !== "#") && (link?.length > 0)
  const target = (targetType == "newTab") ? '_blank' : '_self'

  if (!src) {
    return null
  }

  return (
    <a
      target={target}
      href={link}
      onClick={(e) => {
        if (!isCanLink) {
          e.preventDefault();
          return false;
        }
      }}

      className={classNames(css`
        position: relative;
        height: 100%;
        width: 100%;
        display: flex;
        flex-direction: column;
        justify-content: center;
        align-items: center;
        text-decoration: none;
        margin-bottom: ${marginBottom}px;
        margin-left: ${marginLeft}px;
        margin-right: ${marginRight}px;

        cursor: ${isCanLink ? 'pointer' : 'default'};
        div:hover{
          cursor: ${isCanLink ? 'pointer' : 'default'};
          img:hover{
            cursor: ${isCanLink ? 'pointer' : 'default'};
          }
        }
      `,
      )}
    >
      <div
        className={classNames(css`
          height: ${height};
          width: ${width};
          margin: 0;
        `,
        )}
      >
        <img
          src={src}
          alt={alt}
          className={css`
          height: ${height};
          width: ${width};
          object-fit: ${objectFit};
          overflow: 'hidden';
        `}
        />
      </div>

    </a >
  )
}


ImageWidget.propTypes = {
  link: PropTypes.string,
  src: PropTypes.string,
  alt: PropTypes.string,
  targetType: PropTypes.string,
  objectFit: PropTypes.any,
  height: PropTypes.string,
  width: PropTypes.string,
  marginBottom: PropTypes.number,
};

ImageWidget.defaultProps = {
  src: null,
  link: '#',
  targetType: 'default',
  alt: 'ImageWidget',
  objectFit: 'contain',
  height: '100%',
  width: '100%',
  marginBottom: 0,
};


export default ImageWidget


