import React from "react";
import PropTypes from "prop-types";
import { css } from "@emotion/css";
import tw, { styled } from "twin.macro";
import "../../static/fontello/css/fontello.css";
import Label from "../Label";

const StyledBoxButtonContact = styled.button(({ isSetBorder }) => [
  isSetBorder ? tw`border-[1px] border-white border-solid` : tw`border-0`,
  tw`bg-white rounded-[10px] cursor-pointer z-[1100] min-w-[70px] p-0`,
]);
const StyledDiv = styled.div(({ twProps }) => [twProps]);

const OrderButton = (props) => {
  const {
    data = {},
    theme = { backgroundColor: "#ffffff" },
    pageContact = {},
    renderType = "page_sale",
    isUseBackgroundImage = false
  } = props;

  const isHomePage = renderType == "page_home";

  if (!data) {
    return null;
  }

  const {
    orderButtonStatus = "",
    text = "สั่งซื้อสินค้า",
    backgroundColor = "#26D496",
    fontColor = "#FFFFFF",
  } = data;

  const hexToRGB = (hex) => {
    hex = "0x" + hex;
    let r = (hex >> 16) & 0xff;
    let g = (hex >> 8) & 0xff;
    let b = hex & 0xff;
    return `${r},${g},${b},${0.8}`;
  };

  const color = backgroundColor.slice(1);
  const bgContact = hexToRGB(color);

  const StyleButtonContact = styled.div(() => [
    `
  background: rgba(${bgContact});
        width: 100%;
        // box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
        display: flex;
        justify-content: center;
        align-items: center;
        border-radius: 10px;
        border: none;
        min-height: 44px;
        height: 100%;
        font-size: 18px;
        text-align: center;
        &:hover {
          cursor: pointer;
        }
  `,
  ]);

  const isContactEmpty = Object.values(pageContact).every(
    (item) => item.link == ""
  );

  return (
    <div
      className={`${css`
        width: initial;
        bottom: 0;
        position: sticky;
        z-index: 99;
        background-color: ${isHomePage || renderType == 'page_article' || orderButtonStatus == 'hide' ? 'transparent' : theme.backgroundColor && !isUseBackgroundImage ? theme?.backgroundColor : 'rgba(255,255,255,0.1)'};
        padding: 15px 1rem;
        display: flex;
        background-clip: padding-box;
      `}`}
    >
      {/* ========= button ========= */}
      <div
        className={`${css`
          width: 100%;
          display: flex;
          gap: 10px;
          justify-content: space-between;
          align-items: center;
        `}`}
      >
        <button
          className={css`
            background: ${backgroundColor};
            color: ${fontColor};
            width: 100%;
            border-radius: 10px;
            border: none;
            padding: 8px;
            min-height: 44px;
            font-size: 18px;
            text-align: center;
            &:hover {
              cursor: pointer;
            }
            visibility: ${orderButtonStatus == "" || orderButtonStatus == "hide"
              ? "hidden"
              : "visible"};
          `}
        >
          <StyledDiv twProps={tw`w-full line-clamp-2`}>
            <Label
              text={text}
              fontSize={18}
              fontWeight={400}
              textAlign={"center"}
              color={fontColor}
              twProps={tw`break-all`}
            />
          </StyledDiv>
        </button>

        {/* ========= button contact ========= */}
        {isContactEmpty ? null : (
          <StyledBoxButtonContact isSetBorder={isHomePage}>
            <StyleButtonContact>
              <i
                className={`icon-contact ${css`
                  font-size: 24px;
                  color: ${fontColor};
                `}`}
              />
            </StyleButtonContact>
          </StyledBoxButtonContact>
        )}
      </div>
    </div>
  );
};

OrderButton.propTypes = {
  data: PropTypes.shape({
    orderButtonStatus: PropTypes.string,
    action: PropTypes.any,
    text: PropTypes.string,
    backgroundColor: PropTypes.string,
    fontColor: PropTypes.string,
    contactButtonStatus: PropTypes.string,
    messager: PropTypes.string,
    line: PropTypes.string,
    mobile: PropTypes.string,
  }),
  theme: PropTypes.object,
  pageContact: PropTypes.object,
  renderType: PropTypes.string,
};

OrderButton.defaultProps = {
  data: {
    orderButtonStatus: "",
    action: "",
    text: "สั่งซื้อสินค้า",
    backgroundColor: "#26D496",
    fontColor: "#FFFFFF",
    contactButtonStatus: "",
    messager: "",
    line: "",
    mobile: "",
  },
  theme: {
    backgroundColor: "#ffffff",
  },
  pageContact: {},
  renderType: "page_sale",
};

export default OrderButton;
