import React, { useEffect, useState } from 'react'
import PropTypes from 'prop-types';
import { css } from '@emotion/css'
import tw, { styled } from 'twin.macro'
import classNames from 'classnames';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faCartShopping } from '@fortawesome/free-solid-svg-icons';
import { mockTheme } from '../../defaultTheme';
import Label from '../Label';
import AmountProduct from '../AmountProduct';
import CardOutStock from '../CardOutStock';
import numeral from 'numeral';


const StyledDiv = styled.div(({ twProps }) => [
  twProps,
])

const StyledImg = styled.img(({ twProps }) => [
  twProps,
  {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
  },
])
const StyledBoxImg = styled.div(({ twProps }) => [
  twProps,
  {
    position: 'relative',
    paddingTop: '100%',
  },
])

const StyledButton = styled.button(({ twProps }) => [
  twProps,
])

const StylesProductItem = {
  background: ({ bg }) => [
    {
      backgroundColor: bg,
    }
  ],
  border: ({ border }) => [
    {
      // outline: border ? `2px solid ${border}` : 'none',
      borderRadius: '10px',
      boxShadow: `0px 0px 0px 2px ${border}`
    }
  ],
}




const ProductItem = (props) => {
  const {
    theme,
    data,
    imageChildren,
    marginBottom,

    handleActiveCard,
    isActiveProduct,
    isProductOneSKU,

    handleAddToCart,


    isCanIncrement,
    isCanDecrement,
    handleBtnIncrement,
    handleBtnDecrement,
    inputValue,
  } = props



  const [isActiveCard, setIsActiveCard] = useState(true)
  const [isAnimatePlay, setIsAnimatePlay] = useState(false)


  // useEffect(() => {
  //   if (isProductOneSKU) {
  //     setIsActiveCard(true)
  //   } else {
  //     setIsActiveCard(isActiveProduct)
  //   }
  // }, [isActiveProduct])


  const name = data?.name
  const sku = data?.sku
  const image = data?.image
  const sold = data?.solds
  const remains = data?.remains
  const priceList = data?.priceList
  const priceNet = data?.priceNet
  const indexCard = data?.indexCard


  const adjustColor = (color, amount) => {
    //if(typeof color == "string" )}

    if (typeof color == "string" && color) {
      return '#' + color.replace(/^#/, '').replace(/../g, color => ('0' + Math.min(255, Math.max(0, parseInt(color, 16) + amount)).toString(16)).substr(-2));
    } else {
      return null
    }
  }
  const CBorder = adjustColor(theme?.primary, 50)
  const isOutStock = isProductOneSKU || remains <= 0
  const classActive = tw`transform translate-y-[-100%] translate-y-0 transition duration-500 ease-in`
  const classInActive = tw`transform translate-y-[-100%] translate-y-0 transition duration-500 ease-out`

  if (!data) {
    return null
  }

  return (
    <div
      className={classNames(css`
        position: relative;
        margin-bottom: ${marginBottom}px;
        `,
      )}
      role={(isOutStock) ? "none" : "button"}
      onClick={(event) => {
        // (isOutStock) ? event.stopPropagation() : setIsActiveCard(!isActiveCard); handleActiveCard(indexCard); setIsAnimatePlay(!isOutStock ? true : false)
      }}
    >
      <StyledDiv
        twProps={tw`w-full relative z-[20]`}
      >
        <StyledDiv
          twProps={[
            tw` flex flex-col bg-white overflow-hidden shadow-lg rounded-card `,
            // StylesProductItem.border({ border: (isActiveCard && !isProductOneSKU) && CBorder }),
          ]}
        >

          <div
            className={css`
              aspect-radio: 1/1;
              overflow: hidden;
              position:relative;
            `}
          >
            <CardOutStock
              isShowOutStock={remains <= 0}
              isSizeProductOneSKU={isProductOneSKU}
            />

            {imageChildren ?
              imageChildren
              :
              <StyledBoxImg>
                <StyledImg
                  twProps={tw`object-cover bg-gray text-transparent `}
                  src={image}
                  alt={`cover-${name}`}
                  width={'100%'}
                  height={'100%'}
                // height={'300px'}
                />
              </StyledBoxImg>
            }
          </div>
          <StyledDiv
            twProps={[tw`flex flex-col items-start px-3 pt-3 line-clamp-2`,
            !isProductOneSKU && tw`pb-0`,
            isProductOneSKU && tw`pb-4`,
            ]}
          >
            <StyledDiv
              twProps={tw`w-full line-clamp-1 text-left`}
            >
              <Label
                text={name}
                fontSize={12}
                fontWeight={400}
                textAlign={'start'}
                twColor={tw`text-textTertiary`}
                twProps={tw`break-all`}
              />
            </StyledDiv>

            <StyledDiv
              twProps={tw`w-full line-clamp-2 text-left min-h-[50px]`}
            >
              <Label
                text={sku}
                fontSize={16}
                fontWeight={300}
                textAlign={'start'}
                twProps={tw`whitespace-pre-wrap break-all leading-[25px]`}
              />
            </StyledDiv>

            <StyledDiv
              twProps={[
                tw`flex gap-x-[10px]`,
                isProductOneSKU ? tw`flex-row justify-between items-center` : tw`flex-col`,
              ]}
            >
              <StyledDiv
                twProps={tw`flex flex-col flex-1`}
              >
                <StyledDiv twProps={tw`flex flex-row justify-start`}>

                  <Label
                    text={`฿ ${numeral(priceList).format('0,0[.]00')}`}
                    twColor={tw`text-textDisable`}
                    twProps={priceNet != priceList ? tw`visible` : tw`invisible`}
                    fontSize={12}
                    fontWeight={400}
                    textAlign={'start'}
                    textDecoration={'line-through'}
                  />
                </StyledDiv>
                <StyledDiv twProps={tw`flex flex-row justify-start`}>
                  <Label
                    text={`฿ ${numeral(priceNet).format('0,0[.]00')}`}
                    color={theme?.primary}
                    twProps={tw`mt-[4px]`}
                    fontSize={18}
                    fontWeight={700}
                    textAlign={'start'}
                  />
                </StyledDiv>
              </StyledDiv>
              {
                isProductOneSKU && remains >= 0 && (
                  <StyledDiv
                    twProps={tw`flex flex-col flex-1 items-end`}
                  >
                    <AmountProduct
                      theme={theme}
                      isCanIncrement={remains > 0 ? isCanIncrement : false}
                      isCanDecrement={inputValue > 1 ? isCanDecrement : false}
                      handleBtnIncrement={({ quantityProduct }) => { handleBtnIncrement({ quantityProduct }) }}
                      handleBtnDecrement={({ quantityProduct }) => { handleBtnDecrement({ quantityProduct }) }}
                      inputValue={remains > 0 ? inputValue : 0}
                    />
                  </StyledDiv>
                )
              }

            </StyledDiv>
          </StyledDiv>

          {/* box add to cart */}
          <StyledDiv
            twProps={[
              isActiveCard ? tw`flex flex-col py-[12px]` : tw`flex flex-col`,
              isProductOneSKU && tw`py-0`
            ]}
            className={isAnimatePlay ? (isActiveCard ? 'productPadding' : 'productPadding2') : ''}
          >
            <StyledDiv
              twProps={[
                tw`flex flex-col justify-center text-center py-[0px] invisible hidden`,
                (isActiveCard && !isProductOneSKU) && tw`visible flex px-[12px]`
              ]}
            >
              <AmountProduct
                theme={theme}
                isCanIncrement={remains > 0 ? isCanIncrement : false}
                isCanDecrement={inputValue > 1 ? isCanDecrement : false}
                handleBtnIncrement={({ quantityProduct }) => { handleBtnIncrement({ quantityProduct }) }}
                handleBtnDecrement={({ quantityProduct }) => { handleBtnDecrement({ quantityProduct }) }}
                inputValue={remains > 0 ? inputValue : 0}
              />
              {/* <StyledDiv tw='pt-4'>
                <StyledDiv
                  twProps={tw`pt-4`}
                >
                  <Label
                    text={`ขายแล้ว ${sold} ชิ้น`}
                    twColor={tw`text-iconDisable`}
                    fontSize={12}
                    fontWeight={400}
                  />
                </StyledDiv>
              </StyledDiv> */}
            </StyledDiv>
          </StyledDiv>

          {/* Button add to cart */}
          <StyledButton
            data-cy="btnAddToCart"
            twProps=
            {[remains > 0 && (css`
              cursor: pointer;
                &:hover, :hover {
                  Label{
                    cursor: pointer;
                  }
                }
            `),
            remains <= 0 && (css`
            cursor: default !important;
              &:hover, :hover {
                cursor: default !important;
                svg,path,label,p,div,Label{
                  cursor: default !important;
                }
              }
            `),
            tw`flex flex-row justify-center items-center text-center w-full py-0 border-0 invisible rounded-b-card`,
            remains > 0 && tw`cursor-pointer hover:brightness-[1.08]`,
            StylesProductItem.background({ bg: remains > 0 ? theme?.primary : '#AEAFAF' }),
            ((isActiveCard || isProductOneSKU) && remains >= 0) && tw`visible py-2`,
            ]}
            onClick={(event) => { remains > 0 && handleAddToCart(), event.stopPropagation(); }}
          >
            <FontAwesomeIcon
              icon={faCartShopping}
              color={'#ffffff'}
            />
            <Label
              text={`เพิ่มลงตะกร้า`}
              color={'#ffffff'}
              fontSize={16}
              fontWeight={500}
              // textAlign={'center'}
              twProps={[tw`ml-2`, remains > 0 && tw`cursor-pointer`]}
            />
          </StyledButton>
          {/* Button add to cart */}

          {/* box add to cart */}
        </StyledDiv>

      </StyledDiv>

    </div >
  )
}

ProductItem.propTypes = {
  theme: PropTypes.any,
  data: PropTypes.any,
  imageChildren: PropTypes.any,
  marginBottom: PropTypes.number,

  handleActiveCard: PropTypes.any,
  isActiveProduct: PropTypes.any,
  isProductOneSKU: PropTypes.any,

  handleAddToCart: PropTypes.any,

  //amount product
  isCanIncrement: PropTypes.any,
  isCanDecrement: PropTypes.any,
  handleBtnIncrement: PropTypes.any,
  handleBtnDecrement: PropTypes.any,

  inputValue: PropTypes.number,
  //amount product
};

ProductItem.defaultProps = {
  theme: mockTheme,
  data: null,
  imageChildren: null,
  marginBottom: 0,

  handleActiveCard: null,
  isActiveProduct: false,
  isProductOneSKU: false,

  handleAddToCart: null,

  //amount product
  isCanIncrement: true,
  isCanDecrement: true,
  handleBtnIncrement: null,
  handleBtnDecrement: null,

  inputValue: 0,
  //amount product
};


export default ProductItem