import React from "react";
import PropTypes from "prop-types";
import TitleText from "../TitleText/TitleText";
import { css } from "@emotion/css";
import { styled } from "twin.macro";

const StyleInput = styled.input(({}) => [
  `
    background: #f9f9f9;
    border: 1px solid #f2f2f2;
    border-radius: 10px;
    font-weight: 400;
    font-size: 16px;
    width: -webkit-fill-available;
    padding: 10px 15px;
    margin-top: 5px;
    color: #2A2C2D;
    font-family: 'Kanit', sans-serif;

        &::placeholder {
            color: #aeafaf;
        }

        &:focus {
            outline: none;
        }
  `,
]);

const Register = (props) => {
  const {
    theme = { primary: "#26D496", fontColor: '#2A2C2D' },
    handleChange = null,
    registerList = [],
    headerTitle = "",
  } = props;

  const StyleLabel = styled.label(({}) => [
    `
    color: #AEAFAF;
    font-weight: 400;
    font-size: 12px;
    font-family: 'Kanit', sans-serif;
  `,
  ]);

  const StyleRequest = styled.label(({}) => [
    `
    color: #ED1E46;
    font-weight: 400;
    font-size: 14px;
    font-family: 'Kanit', sans-serif;
    padding-left: 5px;
  `,
  ]);

  return (
    <div>
      <TitleText tagColor={theme?.primary} color={theme?.fontColor}>{headerTitle}</TitleText>

      <div
        className={css`
          background-color: white;
          margin: 10px 0px;
          padding: 10px 15px;
          border-radius: 12px;
        `}
      >
        {registerList.map((item, index) => {
          let labelName = "";
          if (item.key == "name") {
            labelName = "ชื่อ-สกุล";
          } else if (item.key == "mobile") {
            labelName = "โทรศัพท์";
          } else if (item.key == "email") {
            labelName = "อีเมล";
          } else if (item.key == "birthday") {
            labelName = "วันเดือนปีเกิด";
          } else if (item?.key == "sex") {
            return null;
          } else {
            return null;
          }
          return (
            <div
              key={index}
              className={css`
                margin: 20px 0px;
              `}
            >
              <div
                className={css`
                  display: flex;
                `}
              >
                <StyleLabel>{labelName}</StyleLabel>
                <StyleRequest>*</StyleRequest>
              </div>

              {item.key == "birthday" ? (
                <div
                  className={css`
                    position: relative;
                  `}
                >
                  <StyleInput
                    placeholder={"เลือก" + labelName}
                    name={item.label}
                    value={""}
                    onChange={(e) => handleChange(e)}
                    disabled={true}
                  />
                  <i
                    className={`icon-calendar ${css`
                      position: absolute;
                      right: 10px;
                      top: 17px;
                      color: #252527;
                    `}`}
                  />
                </div>
              ) : (
                <StyleInput
                  placeholder={
                    item.key == "mobile"
                      ? "กรอกเบอร์โทรศัพท์"
                      : "กรอก" + labelName
                  }
                  name={item.label}
                  value={""}
                  onChange={(e) => handleChange(e)}
                  disabled={true}
                />
              )}
            </div>
          );
        })}
      </div>
    </div>
  );
};

Register.propTypes = {
  theme: PropTypes.object,
  handleChange: PropTypes.func,
  headerTitle: PropTypes.string,
  registerList: PropTypes.array,
};

Register.defaultProps = {
  theme: { primary: "#26D496", fontColor: '#2A2C2D' },
  handleChange: null,
  headerTitle: "",
  registerList: [],
};

export default Register;
