import React from 'react'
import PropTypes from 'prop-types';
import tw, { styled } from 'twin.macro'
import { css } from '@emotion/css'
import Label from '../Label';
import classNames from 'classnames';
import Line from "../../static/images/share-line.png";
import Facebook from "../../static/images/share-fb.png";
import Twitter from "../../static/images/share-twitter.png";
import Msg from "../../static/images/share-msg.png";

const StyledDiv = styled.div(({ twProps }) => [
  twProps,
])

const StyledImg = styled.img(({ twProps }) => [
  twProps,
])


const ShareSocialMedia = ({
  isCanClick,
  handleShareSocialMedia,
}) => {

  const mediaList = [
    {
      type: 'line',
      icon: Line,
      // icon: '../../static/images/share-line.png',
    },
    {
      type: 'facebook',
      icon: Facebook,
      // icon: '../../static/images/share-fb.png',
    },
    {
      type: 'twitter',
      icon: Twitter,
      // icon: '../../static/images/share-twitter.png',
    },
    {
      type: 'messenger',
      icon: Msg,
      // icon: '../../static/images/share-msg.png',
    },
  ]


  return (
    <StyledDiv
      twProps={tw`flex flex-col items-center justify-center bg-white/10 p-[20px]`}
    >

      <Label
        text={`แชร์หน้าเว็บไปยัง`}
        color={'#ffffff'}
        fontSize={16}
        fontWeight={400}
        twColor={tw`text-textSecondary`}
        twProps={tw`mb-[12px]`}
      />

      <div
        className={classNames(css`
              display: grid;
              grid-template-columns: repeat(4, 1fr);
              gap: 12px;
            `,
        )}
      >
        {
          mediaList.map((item, index) => {
            return (
              <div
                key={`share-${index}`}
                role={isCanClick ? 'button' : 'none'}
                onClick={(event) => {
                  !isCanClick ? event.stopPropagation() : handleShareSocialMedia({ type: item.type })
                }}
              >
                <StyledImg
                  src={item.icon}
                  alt={`media-${item.type}`}
                  width={35}
                  height={35}
                />
              </div>
            )
          })
        }
      </div>


    </StyledDiv >
  );
};


ShareSocialMedia.propTypes = {
  isCanClick: PropTypes.any,
  handleShareSocialMedia: PropTypes.any,
};

ShareSocialMedia.defaultProps = {
  isCanClick: true,
  handleShareSocialMedia: null,
};


export default ShareSocialMedia


