import React from 'react'
import PropTypes from 'prop-types';
import { css } from '@emotion/css'
import classNames from 'classnames'
import { useResizeDetector } from 'react-resize-detector';
import uniqueId from 'lodash/uniqueId'

import ReactPlayer from 'react-player/lazy'



const VideoWidget = (props) => {
  const {
    config,
    url,
    playing,
    controls,
    loop,
    muted,
    volume,
    light,
    width,
    height,
    marginBottom = 0,
    marginLeft = 0,
    marginRight = 0,
    type
  } = props


  if (!url) {
    return null
  }

  const { width: containerWidth, height: containerHeight ,ref } = useResizeDetector()


  return (
    <div
      ref={ref}
      className={classNames(css([
        `margin-bottom: ${marginBottom}px;
        margin-left: ${marginLeft}px;
        margin-right: ${marginRight}px;
        .react-player {
          overflow: hidden;

        }


        div,
        video,
        span {
          width: 100% !important;
         

          aspect-ratio: 16/9 !important;
          margin: 0 auto;
        }
    
        span {
           
        //  height: unset !important;
        //   display: flex !important;
        //   flex-direction: row !important;
        //   justify-content: center !important;
        //   align-items: center;
        //   aspect-ratio: 16/9 !important;
        //   margin: 0 auto;

          iframe {
            position: absolute !important;
            max-height: 100% !important;
            max-width: 100% !important;
            min-width: 100px !important;
            transform: translate(-50%, -50%) !important;
            top: 50% !important;
            left: 50% !important;
            margin: 0 auto;
            aspect-ratio: 16/9 !important;
            video {
              aspect-ratio: 16/9 !important;
            }
          }
        }
      `
    ])
      )}
    >
      <div>
        <ReactPlayer
          key={ type == "video_facebook" ? `player-continer-${uniqueId()}` : `` }
          config={
                    {
                      youtube: {
                        playerVars: { showinfo: 1 }
                      },
                      facebook: {
                        appId: "828385268184846",
                        attributes: {
                          // add css to control video styling
                          width : `${parseInt(containerWidth)}`,
                          height: `${parseInt(containerHeight)}`,
                          padding:0,
                          backgroundColor: '#000',
                          overflow:'hidden'
                        }
                      }
        
                    }
        
                  }
          url={url}
          playing={playing}
          controls={controls}
          loop={loop}
          muted={muted}
          volume={volume}
          light={light}
          width={width}
          height={height}

          style={{
            backgroundColor: '#000000',
            width: '100%',
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
          }}
        />
      </div>
    </div >
  )
}


VideoWidget.propTypes = {
//   config: PropTypes.any,
  url: PropTypes.string,
  playing: PropTypes.any,
  controls: PropTypes.any,
  loop: PropTypes.any,
  muted: PropTypes.any,
  volume: PropTypes.number,
  light: PropTypes.any,
  width: PropTypes.string,
  height: PropTypes.string,
  marginBottom: PropTypes.number
};

VideoWidget.defaultProps = {
//   config: configPlayer,
  url: null,
  playing: false,
  controls: true,
  loop: false,
  muted: false,
  volume: 1,
  light: false,
  width: 'auto',
  height: 'auto',
  marginBottom: 0
};


export default VideoWidget