/** @type {import('tailwindcss').Config} */

module.exports = {
  mode: 'jit',
  purge: [
    './src/*.{js,jsx,ts,tsx}',
    './src/**/*.{js,jsx,ts,tsx}',
    './src/**/**/*.{js,jsx,ts,tsx}',
    './src/components/**/*.{js,jsx,ts,tsx}',
  ],
  content: [
    './src/*.{js,jsx,ts,tsx}',
    './src/**/*.{js,jsx,ts,tsx}',
    './src/**/**/*.{js,jsx,ts,tsx}',
    './src/components/**/*.{js,jsx,ts,tsx}',
  ],
  theme: {
    aspectRatio: {
      auto: 'auto',
      square: '1 / 1',
      video: '16 / 9',
      1: '1',
      2: '2',
      3: '3',
      4: '4',
      5: '5',
      6: '6',
      7: '7',
      8: '8',
      9: '9',
      10: '10',
      11: '11',
      12: '12',
      13: '13',
      14: '14',
      15: '15',
      16: '16',
    },
    screens: {
      'sm': '480px',
      'ls': '640px',
      'md': '768px',
      'lg': '1024px',
      'xl': '1280px',
      '2xl': '1536px',
    },
    colors: {
      transparent: 'transparent',
      current: 'currentColor',
      primary: '#95BAA8',
      secondary: '#ecc94b',
      bgGray: '#F9F9F9',
      bgBody: '#F9F9F9',
      bgVideo: '#333333',
      bgInput: '#F2F2F2',
      bgToast: '#090909',
      borderGray: '#E9E9E9',
      defaultBG: '#f9f9f9',
      defaultLabel: '#2A2C2D',
      defaultTextInput: '#aeafaf',
      defaultErrorDark: '#c81f4c',
      defaultErrorBg: '#FEF5F4',
      defaultErrorSubordinate: '#ED1E46',
      defaultWhite: '#ffffff',
      defaultTextPrimary: '#2a2c2d',
      defaultBdark: '#141414',
      defaultActionIcon: '#808081',
      actionBorder: '#f3f3f3',
      textPrimary: '#383633',
      textTertiary: '#6B6B6B',
      textSecondary: '#444450',
      textDisable: '#6B6B6B',
      iconDisable: '#DBDBDB',
      iconDefault: '#252527',
      iconSearch: '#AFAEAE',
      'black': '#000000',
      'white': '#ffffff',
      'blue': '#1fb6ff',
      'red': '#ff0000',
      'purple': '#7e5bef',
      'pink': '#ff49db',
      'orange': '#ff7849',
      'green': '#13ce66',
      'yellow': '#ffc82c',
      'gray': '#E5E8EC',
      'gray-light': '#d3dce6',
      'gray-dark': '#273444',
      'tahiti': {
        DEFAULT: '#06b6d4',
        100: '#cffafe',
        200: '#a5f3fc',
        300: '#67e8f9',
        400: '#22d3ee',
        500: '#06b6d4',
        600: '#0891b2',
        700: '#0e7490',
        800: '#155e75',
        900: '#164e63',
      },
    },
    opacity: {
      '0': '0',
      '10': '0.1',
      '20': '0.2',
      '30': '0.3',
      '40': '0.4',
      '50': '0.5',
      '60': '0.6',
      '70': '0.7',
      '80': '0.8',
      '90': '0.9',
      '100': '1',
    },
    fontFamily: {
      sans: ["Kanit", "sans-serif"],
      serif: ["Kanit", "sans-serif"],
      body: ["Kanit", "sans-serif"],
    },
    minWidth: {
      '1/2': '50%',
    },
    maxWidth: {
      '1/2': '50%',
    },
    extend: {
      boxShadow: {
        'cardSalePage': '4.68259px 4.68259px 16.3891px rgba(41, 45, 47, 0.1), -4.68259px 4.68259px 18.7304px rgba(255, 255, 255, 0.6);',
      },
      spacing: {
        px: '1px',
        0: '0',
        0.5: '0.125rem',
        1: '0.25rem',
        1.5: '0.375rem',
        2: '0.5rem',
        2.5: '0.625rem',
        3: '0.75rem',
        3.5: '0.875rem',
        4: '1rem',
        5: '1.25rem',
        6: '1.5rem',
        7: '1.75rem',
        8: '2rem',
        9: '2.25rem',
        10: '2.5rem',
        11: '2.75rem',
        12: '3rem',
        14: '3.5rem',
        16: '4rem',
        20: '5rem',
        24: '6rem',
        28: '7rem',
        32: '8rem',
        36: '9rem',
        40: '10rem',
        44: '11rem',
        48: '12rem',
        52: '13rem',
        56: '14rem',
        60: '15rem',
        64: '16rem',
        72: '18rem',
        80: '20rem',
        96: '24rem',
      },
      borderRadius: {
        'none': '0',
        DEFAULT: '.25rem',
        'sm': '.125rem',
        'lg': '.5rem',
        'full': '9999px',
        card: '10px',
        circle: '50%',
      },
      zIndex: {
        '9000': '9000',
        '8000': '8000',
        '7000': '7000',
        '6000': '6000',
        '5000': '5000',
        '4000': '4000',
        '3000': '3000',
        '2000': '2000',
        '1000': '1000',
        '900': '900',
        '800': '800',
        '700': '700',
        '600': '600',
        '500': '500',
        '400': '400',
        '300': '300',
        '200': '200',
        '100': '100',
        '90': '90',
        '80': '80',
        '70': '70',
        '60': '60',
        '50': '50',
        '40': '40',
        '30': '30',
        '20': '20',
        '10': '10',
        '90': '9',
        '80': '8',
        '70': '7',
        '60': '6',
        '50': '5',
        '40': '4',
        '30': '3',
        '20': '2',
        '10': '1',
      },
    }
  },
  variants: {
    aspectRatio: ['responsive', 'hover']
  },
  corePlugins: {
    aspectRatio: false,
  },
  plugins: [
    require('@tailwindcss/line-clamp'),
    require('@tailwindcss/aspect-ratio'),
  ],
}
